@@ -1,12 +1,14 @@
 #!/usr/bin/env python3
 
-import base64
 import os
 import pickle
 import re
 import string
 from copy import deepcopy
 from itertools import product
+import hashlib
+from pathlib import Path
+from collections import defaultdict
 
 import ruamel.yaml
 from ruamel.yaml.compat import StringIO
@@ -17,6 +19,7 @@ from osaca.parser import ParserX86ATT
 
 class MachineModel(object):
     WILDCARD = '*'
+    INTERNAL_VERSION = 1  # increase whenever self._data format changes to invalidate cache!
 
     def __init__(self, arch=None, path_to_yaml=None, isa=None, lazy=False):
         if not arch and not path_to_yaml:
@@ -39,7 +42,7 @@ class MachineModel(object):
                 'load_throughput_default': [],
                 'ports': [],
                 'port_model_scheme': None,
-                'instruction_forms': [],
+                'instruction_forms': []
             }
         else:
             if arch and path_to_yaml:
@@ -49,7 +52,7 @@ class MachineModel(object):
             yaml = self._create_yaml_object()
             if arch:
                 self._arch = arch.lower()
-                self._path = utils.find_file(self._arch + '.yml')
+                self._path = utils.find_datafile(self._arch + '.yml')
             # check if file is cached
             cached = self._get_cached(self._path) if not lazy else False
             if cached:
@@ -59,8 +62,6 @@ class MachineModel(object):
                 with open(self._path, 'r') as f:
                     if not lazy:
                         self._data = yaml.load(f)
-                        # cache file for next call
-                        self._write_in_cache(self._path, self._data)
                     else:
                         file_content = ''
                         line = f.readline()
@@ -69,21 +70,26 @@ class MachineModel(object):
                             line = f.readline()
                         self._data = yaml.load(file_content)
                         self._data['instruction_forms'] = []
-            # separate multi-alias instruction forms
-            for entry in [
-                x for x in self._data['instruction_forms'] if isinstance(x['name'], list)
-            ]:
-                for name in entry['name']:
-                    new_entry = {'name': name}
-                    for k in [x for x in entry.keys() if x != 'name']:
-                        new_entry[k] = entry[k]
-                    self._data['instruction_forms'].append(new_entry)
-                # remove old entry
-                self._data['instruction_forms'].remove(entry)
-            # For use with dict instead of list as DB
-            # self._data['instruction_dict'] = (
-            #     self._convert_to_dict(self._data['instruction_forms'])
-            # )
+                # separate multi-alias instruction forms
+                for entry in [x for x in self._data['instruction_forms']
+                              if isinstance(x['name'], list)]:
+                    for name in entry['name']:
+                        new_entry = {'name': name}
+                        for k in [x for x in entry.keys() if x != 'name']:
+                            new_entry[k] = entry[k]
+                        self._data['instruction_forms'].append(new_entry)
+                    # remove old entry
+                    self._data['instruction_forms'].remove(entry)
+                # Normalize instruction_form names (to UPPERCASE) and build dict for faster access:
+                self._data['instruction_forms_dict'] = defaultdict(list)
+                for iform in self._data['instruction_forms']:
+                    iform['name'] = iform['name'].upper()
+                    self._data['instruction_forms_dict'][iform['name']].append(iform)
+                self._data['internal_version'] = self.INTERNAL_VERSION
+
+                if not lazy:
+                    # cache internal representation for future use
+                    self._write_in_cache(self._path)
 
     def __getitem__(self, key):
         """Return configuration entry."""
@@ -98,36 +104,21 @@ class MachineModel(object):
     def get_instruction(self, name, operands):
         """Find and return instruction data from name and operands."""
         # For use with dict instead of list as DB
-        # return self.get_instruction_from_dict(name, operands)
         if name is None:
             return None
+        name_matched_iforms = self._data['instruction_forms_dict'].get(name.upper(), [])
         try:
             return next(
                 instruction_form
-                for instruction_form in self._data['instruction_forms']
-                if instruction_form['name'].upper() == name.upper()
-                and self._match_operands(
+                for instruction_form in name_matched_iforms if self._match_operands(
                     instruction_form['operands'] if 'operands' in instruction_form else [],
-                    operands,
-                )
-            )
+                    operands))
         except StopIteration:
             return None
         except TypeError as e:
             print('\nname: {}\noperands: {}'.format(name, operands))
             raise TypeError from e
 
-    def get_instruction_from_dict(self, name, operands):
-        """Find and return instruction data from name and operands stored in dictionary."""
-        if name is None:
-            return None
-        try:
-            # Check if key is in dict
-            instruction_form = self._data['instruction_dict'][self._get_key(name, operands)]
-            return instruction_form
-        except KeyError:
-            return None
-
     def average_port_pressure(self, port_pressure):
         """Construct average port pressure list from instruction data."""
         port_list = self._data['ports']
@@ -234,12 +225,13 @@ class MachineModel(object):
                 for y in list(filter(lambda x: True if x != 'class' else False, op))
             ]
             operands.append('{}({})'.format(op['class'], ','.join(op_attrs)))
-        return '{}  {}'.format(instruction_form['name'], ','.join(operands))
+        return '{}  {}'.format(instruction_form['name'].lower(), ','.join(operands))
 
     @staticmethod
     def get_isa_for_arch(arch):
         """Return ISA for given micro-arch ``arch``."""
         arch_dict = {
+            'a64fx': 'aarch64',
             'tx2': 'aarch64',
             'n1': 'aarch64',
             'zen1': 'x86',
@@ -293,7 +285,8 @@ class MachineModel(object):
             {
                 k: v
                 for k, v in self._data.items()
-                if k not in ['instruction_forms', 'load_throughput']
+                if k not in ['instruction_forms', 'instruction_forms_dict', 'load_throughput',
+                             'internal_version']
             },
             stream,
         )
@@ -313,37 +306,54 @@ class MachineModel(object):
         :type filepath: str
         :returns: cached DB if existing, `False` otherwise
         """
-        hashname = self._get_hashname(filepath)
-        cachepath = utils.exists_cached_file(hashname + '.pickle')
-        if cachepath:
-            # Check if modification date of DB is older than cached version
-            if os.path.getmtime(filepath) < os.path.getmtime(cachepath):
-                # load cached version
-                with open(cachepath, 'rb') as f:
-                    cached_db = pickle.load(f)
-                return cached_db
-            else:
-                # DB newer than cached version --> delete cached file and return False
-                os.remove(cachepath)
+        p = Path(filepath)
+        hexhash = hashlib.sha256(p.read_bytes()).hexdigest()
+
+        # 1. companion cachefile: same location, with '.<name>_<sha512hash>.pickle'
+        companion_cachefile = p.with_name('.' + p.stem + '_' + hexhash).with_suffix('.pickle')
+        if companion_cachefile.exists():
+            # companion file (must be up-to-date, due to equal hash)
+            with companion_cachefile.open('rb') as f:
+                data = pickle.load(f)
+            if data.get('internal_version') == self.INTERNAL_VERSION:
+                return data
+
+        # 2. home cachefile: ~/.osaca/cache/<name>_<sha512hash>.pickle
+        home_cachefile = (Path(utils.CACHE_DIR) / (p.stem + '_' + hexhash)).with_suffix('.pickle')
+        if home_cachefile.exists():
+            # home file (must be up-to-date, due to equal hash)
+            with home_cachefile.open('rb') as f:
+                data = pickle.load(f)
+            if data.get('internal_version') == self.INTERNAL_VERSION:
+                return data
         return False
 
-    def _write_in_cache(self, filepath, data):
+    def _write_in_cache(self, filepath):
         """
         Write machine model to cache
 
         :param filepath: path to store DB
         :type filepath: str
-        :param data: :class:`MachineModel` to store
-        :type data: :class:`dict`
         """
-        hashname = self._get_hashname(filepath)
-        filepath = os.path.join(utils.CACHE_DIR, hashname + '.pickle')
-        with open(filepath, 'wb') as f:
-            pickle.dump(data, f)
+        p = Path(filepath)
+        hexhash = hashlib.sha256(p.read_bytes()).hexdigest()
+        # 1. companion cachefile: same location, with '.<name>_<sha512hash>.pickle'
+        companion_cachefile = p.with_name('.' + p.stem + '_' + hexhash).with_suffix('.pickle')
+        if os.access(str(companion_cachefile.parent), os.W_OK):
+            with companion_cachefile.open('wb') as f:
+                pickle.dump(self._data, f)
+                return
 
-    def _get_hashname(self, name):
-        """Returns unique hashname for machine model"""
-        return base64.b64encode(name.encode()).decode()
+        # 2. home cachefile: ~/.osaca/cache/<name>_<sha512hash>.pickle
+        cache_dir = Path(utils.CACHE_DIR)
+        try:
+            os.makedirs(cache_dir, exist_ok=True)
+        except OSError:
+            return
+        home_cachefile = (cache_dir / (p.stem + '_' + hexhash)).with_suffix('.pickle')
+        if os.access(str(home_cachefile.parent), os.W_OK):
+            with home_cachefile.open('wb') as f:
+                pickle.dump(self._data, f)
 
     def _get_key(self, name, operands):
         """Get unique instruction form key for dict DB."""
@@ -353,18 +363,6 @@ class MachineModel(object):
         key_string += '_'.join([self._get_operand_hash(op) for op in operands])
         return key_string
 
-    def _convert_to_dict(self, instruction_forms):
-        """Convert list DB to dict DB"""
-        instruction_dict = {}
-        for instruction_form in instruction_forms:
-            instruction_dict[
-                self._get_key(
-                    instruction_form['name'],
-                    instruction_form['operands'] if 'operands' in instruction_form else None,
-                )
-            ] = instruction_form
-        return instruction_dict
-
     def _get_operand_hash(self, operand):
         """Get unique key for operand for dict DB"""
         operand_string = ''
@@ -493,6 +491,7 @@ class MachineModel(object):
         if 'class' in operand:
             # compare two DB entries
             return self._compare_db_entries(i_operand, operand)
+        # TODO support class wildcards
         # register
         if 'register' in operand:
             if i_operand['class'] != 'register':
@@ -504,12 +503,14 @@ class MachineModel(object):
                 return False
             return self._is_AArch64_mem_type(i_operand, operand['memory'])
         # immediate
+        # TODO support wildcards
         if 'value' in operand or ('immediate' in operand and 'value' in operand['immediate']):
             return i_operand['class'] == 'immediate' and i_operand['imd'] == 'int'
         if 'float' in operand or ('immediate' in operand and 'float' in operand['immediate']):
             return i_operand['class'] == 'immediate' and i_operand['imd'] == 'float'
         if 'double' in operand or ('immediate' in operand and 'double' in operand['immediate']):
             return i_operand['class'] == 'immediate' and i_operand['imd'] == 'double'
+        # identifier
         if 'identifier' in operand or (
             'immediate' in operand and 'identifier' in operand['immediate']
         ):
@@ -580,7 +581,11 @@ class MachineModel(object):
 
     def _is_x86_reg_type(self, i_reg, reg, consider_masking=False):
         """Check if register type match."""
-        i_reg_name = i_reg if not consider_masking else i_reg['name']
+        i_reg_name = i_reg['name'] if i_reg and 'name' in i_reg else i_reg
+        if reg is None:
+            if i_reg is None:
+                return True
+            return False
         # check for wildcards
         if i_reg_name == self.WILDCARD or reg['name'] == self.WILDCARD:
             return True
