@@ -2,7 +2,7 @@
 from itertools import chain
 
 from osaca import utils
-from osaca.parser import AttrDict, ParserAArch64v81, ParserX86ATT
+from osaca.parser import AttrDict, ParserAArch64, ParserX86ATT
 
 from .hw_model import MachineModel
 
@@ -26,12 +26,12 @@ class ISASemantics(object):
 
     def __init__(self, isa, path_to_yaml=None):
         self._isa = isa.lower()
-        path = utils.find_file('isa/' + self._isa + '.yml') if not path_to_yaml else path_to_yaml
+        path = path_to_yaml or utils.find_datafile('isa/' + self._isa + '.yml')
         self._isa_model = MachineModel(path_to_yaml=path)
         if self._isa == 'x86':
             self._parser = ParserX86ATT()
         elif self._isa == 'aarch64':
-            self._parser = ParserAArch64v81()
+            self._parser = ParserAArch64()
 
     def process(self, instruction_forms):
         """Process a list of instruction forms."""
@@ -52,7 +52,6 @@ class ISASemantics(object):
             return
         # check if instruction form is in ISA yaml, otherwise apply standard operand assignment
         # (one dest, others source)
-        # import pdb; pdb.set_trace()
         isa_data = self._isa_model.get_instruction(
             instruction_form['instruction'], instruction_form['operands']
         )
@@ -103,14 +102,14 @@ class ISASemantics(object):
                 if ('post_indexed' in operand['memory'] and operand['memory']['post_indexed']) or (
                     'pre_indexed' in operand['memory'] and operand['memory']['pre_indexed']
                 ):
-                    op_dict['source'].remove(operand)
-                    op_dict['src_dst'].append(operand)
+                    op_dict['src_dst'].append(AttrDict.convert_dict(
+                        {'register': operand['memory']['base']}))
             for operand in [op for op in op_dict['destination'] if 'memory' in op]:
                 if ('post_indexed' in operand['memory'] and operand['memory']['post_indexed']) or (
                     'pre_indexed' in operand['memory'] and operand['memory']['pre_indexed']
                 ):
-                    op_dict['destination'].remove(operand)
-                    op_dict['src_dst'].append(operand)
+                    op_dict['src_dst'].append(AttrDict.convert_dict(
+                        {'register': operand['memory']['base']}))
         # store operand list in dict and reassign operand key/value pair
         instruction_form['semantic_operands'] = AttrDict.convert_dict(op_dict)
         # assign LD/ST flags
