@@ -8,12 +8,13 @@ suite = unittest.TestLoader().loadTestsFromNames(
     [
         'test_base_parser',
         'test_parser_x86att',
-        'test_parser_AArch64v81',
+        'test_parser_AArch64',
         'test_marker_utils',
         'test_semantics',
         'test_frontend',
         'test_db_interface',
         'test_kerncraftAPI',
+        'test_cli',
     ]
 )
 
