@@ -7,7 +7,7 @@ import os
 import unittest
 
 from osaca.frontend import Frontend
-from osaca.parser import ParserAArch64v81, ParserX86ATT
+from osaca.parser import ParserAArch64, ParserX86ATT
 from osaca.semantics import ArchSemantics, KernelDG, MachineModel
 
 
@@ -20,10 +20,10 @@ class TestFrontend(unittest.TestCase):
     def setUpClass(self):
         # set up parser and kernels
         self.parser_x86 = ParserX86ATT()
-        self.parser_AArch64 = ParserAArch64v81()
-        with open(self._find_file('kernel-x86.s')) as f:
+        self.parser_AArch64 = ParserAArch64()
+        with open(self._find_file('kernel_x86.s')) as f:
             code_x86 = f.read()
-        with open(self._find_file('kernel-AArch64.s')) as f:
+        with open(self._find_file('kernel_aarch64.s')) as f:
             code_AArch64 = f.read()
         self.kernel_x86 = self.parser_x86.parse_file(code_x86)
         self.kernel_AArch64 = self.parser_AArch64.parse_file(code_AArch64)
@@ -33,7 +33,7 @@ class TestFrontend(unittest.TestCase):
             path_to_yaml=os.path.join(self.MODULE_DATA_DIR, 'csx.yml')
         )
         self.machine_model_tx2 = MachineModel(
-            path_to_yaml=os.path.join(self.MODULE_DATA_DIR, 'tx2.yml')
+            arch='tx2'
         )
         self.semantics_csx = ArchSemantics(
             self.machine_model_csx, path_to_yaml=os.path.join(self.MODULE_DATA_DIR, 'isa/x86.yml')
@@ -67,13 +67,15 @@ class TestFrontend(unittest.TestCase):
     def test_frontend_x86(self):
         dg = KernelDG(self.kernel_x86, self.parser_x86, self.machine_model_csx)
         fe = Frontend(path_to_yaml=os.path.join(self.MODULE_DATA_DIR, 'csx.yml'))
-        fe.print_throughput_analysis(self.kernel_x86, show_cmnts=False)
-        fe.print_latency_analysis(dg.get_critical_path())
+        fe.throughput_analysis(self.kernel_x86, show_cmnts=False)
+        fe.latency_analysis(dg.get_critical_path())
+        # TODO compare output with checked string
 
     def test_frontend_AArch64(self):
         dg = KernelDG(self.kernel_AArch64, self.parser_AArch64, self.machine_model_tx2)
         fe = Frontend(path_to_yaml=os.path.join(self.MODULE_DATA_DIR, 'tx2.yml'))
-        fe.print_full_analysis(self.kernel_AArch64, dg, verbose=True)
+        fe.full_analysis(self.kernel_AArch64, dg, verbose=True)
+        # TODO compare output with checked string
 
     ##################
     # Helper functions
