@@ -9,7 +9,7 @@ import unittest
 from collections import OrderedDict
 
 from osaca.api import KerncraftAPI
-from osaca.parser import ParserAArch64v81, ParserX86ATT
+from osaca.parser import ParserAArch64, ParserX86ATT
 
 
 class TestKerncraftAPI(unittest.TestCase):
@@ -17,10 +17,10 @@ class TestKerncraftAPI(unittest.TestCase):
     def setUpClass(self):
         # set up parser and kernels
         self.parser_x86 = ParserX86ATT()
-        self.parser_AArch64 = ParserAArch64v81()
-        with open(self._find_file('triad-x86-iaca.s')) as f:
+        self.parser_AArch64 = ParserAArch64()
+        with open(self._find_file('triad_x86_iaca.s')) as f:
             self.code_x86 = f.read()
-        with open(self._find_file('triad-arm-iaca.s')) as f:
+        with open(self._find_file('triad_arm_iaca.s')) as f:
             self.code_AArch64 = f.read()
 
     ###########
@@ -49,7 +49,8 @@ class TestKerncraftAPI(unittest.TestCase):
         )
         self.assertEqual(kapi.get_port_occupation_cycles(), port_occupation)
         self.assertEqual(kapi.get_total_throughput(), 2.0)
-        self.assertEqual(kapi.get_latency(), (1.0, 13.0))
+        # TODO: LCD would be 2 with OF flag LCD --> still to discuss
+        self.assertEqual(kapi.get_latency(), (1.0, 8.0))
 
     def test_kerncraft_API_AArch64(self):
         kapi = KerncraftAPI('tx2', self.code_AArch64)
@@ -62,7 +63,7 @@ class TestKerncraftAPI(unittest.TestCase):
                 ('0DV', 0.0),
                 ('1', 34.0),
                 ('1DV', 0.0),
-                ('2', 2.0),
+                ('2', 3.0),
                 ('3', 64.0),
                 ('4', 64.0),
                 ('5', 32.0),
